Reference
=========

.. toctree::
   :maxdepth: 1

   biso


.. currentmodule:: dibisoplot.biso

BiSO
----

.. autosummary::

   Biso.__init__
   Biso.get_figure
   AnrProjects.__init__
   AnrProjects.fetch_data
   Chapters.__init__
   Chapters.fetch_data
   Chapters.get_figure
   CollaborationMap.__init__
   CollaborationMap.fetch_data
   CollaborationMap.get_figure
   CollaborationNames.__init__
   CollaborationNames.fetch_data
   Conferences.__init__
   Conferences.fetch_data
   EuropeanProjects.__init__
   EuropeanProjects.fetch_data
   Journals.__init__
   Journals.fetch_data
   Journals.get_figure
   OpenAccessWorks.__init__
   OpenAccessWorks.fetch_data
   OpenAccessWorks.get_figure
   WorksType.__init__
   WorksType.fetch_data
